using System;
using System.Collections;
using System.ComponentModel;
using System.ComponentModel.Design;
using System.Drawing;
using System.Drawing.Design;
using System.Windows.Forms;
using System.Windows.Forms.Design;
using System.Windows.Forms.Design.Behavior;
using TraxView.AgTrax.Shared;
using Infragistics.Shared;
using Infragistics.Win;
using Infragistics.Win.UltraWinMaskedEdit;
using Infragistics.Win.UltraWinEditors;

namespace TraxView.AgTrax.Shared.BaseClasses
{
    [System.Security.Permissions.PermissionSet(System.Security.Permissions.SecurityAction.Demand, Name = "FullTrust")]
    public class CurrencyEditorBaseDesigner : ControlDesigner
    {
        #region .   Variables   .
        // References to designer services, for convenience.
        private IComponentChangeService changeService = null;
        private ISelectionService selectionService = null;
        private BehaviorService behaviorSvc = null;

        // This is the collection of DesignerActionLists that
        // defines the smart tags offered on the control. 
        private DesignerActionListCollection actionLists = null;
        #endregion

        #region .   Currency Editor Designer   .
        public CurrencyEditorBaseDesigner()
        {   
        }

        #region .   Dispose   .
        protected override void Dispose(bool disposing)
        {
            if (disposing)
            {
            }

            base.Dispose(disposing);
        }
        #endregion

        #region .   Initialize   .
        // This method is where the designer initializes its state when
        // it is created.
        public override void Initialize(IComponent component)
        {
            base.Initialize(component);

            // Connect to various designer services.
            InitializeServices();
        }

        #region .   New Component   .
        // This demonstrates changing the appearance of a control while
        // it is being designed. In this case, the BackColor property is
        // set to LightBlue. 
        public override void InitializeNewComponent(IDictionary defaultValues)
        {
            base.InitializeNewComponent(defaultValues);
        }
        #endregion

        #region .   Services   .
        // This utility method connects the designer to various services.
        // These references are cached for convenience.
        private void InitializeServices()
        {
            // Acquire a reference to IComponentChangeService.
            this.changeService =
                GetService(typeof(IComponentChangeService))
                as IComponentChangeService;

            // Acquire a reference to ISelectionService.
            this.selectionService =
                GetService(typeof(ISelectionService))
                as ISelectionService;

            // Acquire a reference to BehaviorService.
            this.behaviorSvc =
                GetService(typeof(BehaviorService))
                as BehaviorService;
        }
        #endregion

        #endregion

        #endregion

        #region .   Designer Action List   .
        // This method creates the DesignerActionList on demand, causing
        // smart tags to appear on the control being designed.
        public override DesignerActionListCollection ActionLists
        {
            get
            {
                if (null == actionLists)
                {
                    actionLists = new DesignerActionListCollection();

                    actionLists.Add(
                        new ActionList(this.Component));
                }

                return actionLists;
            }
        }
        #endregion

        public class ActionList : System.ComponentModel.Design.DesignerActionList, IEditType
        {
            #region .   Designer Action List   .
            // Cache a reference to the control.
            private CurrencyEditorBase relatedControl;

            //The constructor associates the control with the smart tag list.
            public ActionList(IComponent component)
                : base(component)
            {
                this.relatedControl = component as CurrencyEditorBase;
            }
            #endregion

            #region .   Variables   .

            #region .   BackColor   .
            public Color BackColorCurrencyEditor
            {
                get
                {
                    return this.relatedControl.BackColorCurrencyEditor;
                }
                set
                {
                    PropertyDescriptor pdAnchor = TypeDescriptor.GetProperties(this.relatedControl)["BackColorCurrencyEditor"];
                    pdAnchor.SetValue(this.relatedControl, value);
                }
            }
            #endregion

            #region .   BackColor Disabled   .
            public Color BackColorDisabledCurrencyEditor
            {
                get
                {
                    return this.relatedControl.BackColorDisabledCurrencyEditor;
                }
                set
                {
                    PropertyDescriptor pdAnchor = TypeDescriptor.GetProperties(this.relatedControl)["BackColorDisabledCurrencyEditor"];
                    pdAnchor.SetValue(this.relatedControl, value);
                }
            }
            #endregion

            #region .   Border Style   .
            public UIElementBorderStyle BorderStyleCurrencyEditor
            {
                get
                {
                    return this.relatedControl.BorderStyleCurrencyEditor;
                }
                set
                {
                    PropertyDescriptor pdAnchor = TypeDescriptor.GetProperties(this.relatedControl)["BorderStyleCurrencyEditor"];
                    pdAnchor.SetValue(this.relatedControl, value);
                }
            }
            #endregion

            #region .   Use Os Themes   .
            // Properties that are targets of DesignerActionPropertyItem entries.
            public DefaultableBoolean UseOsThemes
            {
                get
                {
                    return this.relatedControl.UseOsThemes;
                }
                set
                {
                    PropertyDescriptor pdAnchor = TypeDescriptor.GetProperties(this.relatedControl)["UseOsThemes"];
                    pdAnchor.SetValue(this.relatedControl, value);
                }
            }
            #endregion

            #region .   Spin Button Display Style   .
            // Properties that are targets of DesignerActionPropertyItem entries.
            public ButtonDisplayStyle SpinButtonDisplayStyle
            {
                get
                {
                    return this.relatedControl.SpinButtonDisplayStyle;
                }
                set
                {
                    PropertyDescriptor pdAnchor = TypeDescriptor.GetProperties(this.relatedControl)["SpinButtonDisplayStyle"];
                    pdAnchor.SetValue(this.relatedControl, value);
                }
            }
            #endregion

            #region .   Mask Input   .
            // Properties that are targets of DesignerActionPropertyItem entries.
            [Editor(typeof(MaskUITypeEditor), typeof(UITypeEditor))]
            [TypeConverter(typeof(MaskTypeConverter))]
            public virtual string MaskInput
            {
                get
                {
                    return this.relatedControl.MaskInput;
                }
                set
                {
                    PropertyDescriptor pdAnchor = TypeDescriptor.GetProperties(this.relatedControl)["MaskInput"];
                    pdAnchor.SetValue(this.relatedControl, value);
                }
            }
            #endregion

            #region .   Spin Button Alignment   .
            // Properties that are targets of DesignerActionPropertyItem entries.
            public ButtonAlignment SpinButtonAlignment
            {
                get
                {
                    return this.relatedControl.SpinButtonAlignment;
                }
                set
                {
                    PropertyDescriptor pdAnchor = TypeDescriptor.GetProperties(this.relatedControl)["SpinButtonAlignment"];
                    pdAnchor.SetValue(this.relatedControl, value);
                }
            }
            #endregion

            #region .   Spin Wrap   .
            // Properties that are targets of DesignerActionPropertyItem entries.
            public bool SpinWrap
            {
                get
                {
                    return this.relatedControl.SpinWrap;
                }
                set
                {
                    PropertyDescriptor pdAnchor = TypeDescriptor.GetProperties(this.relatedControl)["SpinWrap"];
                    pdAnchor.SetValue(this.relatedControl, value);
                }
            }
            #endregion

            #region .   Format String   .
            // Properties that are targets of DesignerActionPropertyItem entries.
            public string FormatString
            {
                get
                {
                    return this.relatedControl.FormatString;
                }
                set
                {
                    PropertyDescriptor pdAnchor = TypeDescriptor.GetProperties(this.relatedControl)["FormatString"];
                    pdAnchor.SetValue(this.relatedControl, value);
                }
            }
            #endregion

            #region .   Minimum Value   .
            // Properties that are targets of DesignerActionPropertyItem entries.
            public decimal MinValue
            {
                get
                {
                    return this.relatedControl.MinValue;
                }
                set
                {
                    PropertyDescriptor pdAnchor = TypeDescriptor.GetProperties(this.relatedControl)["MinValue"];
                    pdAnchor.SetValue(this.relatedControl, value);
                }
            }
            #endregion

            #region .   Maximum Value   .
            // Properties that are targets of DesignerActionPropertyItem entries.
            public decimal MaxValue
            {
                get
                {
                    return this.relatedControl.MaxValue;
                }
                set
                {
                    PropertyDescriptor pdAnchor = TypeDescriptor.GetProperties(this.relatedControl)["MaxValue"];
                    pdAnchor.SetValue(this.relatedControl, value);
                }
            }
            #endregion

            #region .   Prompt Character   .
            // Properties that are targets of DesignerActionPropertyItem entries.
            public char PromptChar
            {
                get
                {
                    return this.relatedControl.PromptChar;
                }
                set
                {
                    PropertyDescriptor pdAnchor = TypeDescriptor.GetProperties(this.relatedControl)["PromptChar"];
                    pdAnchor.SetValue(this.relatedControl, value);
                }
            }
            #endregion

            #region .   Tab Navigation   .
            // Properties that are targets of DesignerActionPropertyItem entries.
            public MaskedEditTabNavigation TabNavigation
            {
                get
                {
                    return this.relatedControl.TabNavigation;
                }
                set
                {
                    PropertyDescriptor pdAnchor = TypeDescriptor.GetProperties(this.relatedControl)["TabNavigation"];
                    pdAnchor.SetValue(this.relatedControl, value);
                }
            }
            #endregion

            #region .   Mask Clip Mode   .
            // Properties that are targets of DesignerActionPropertyItem entries.
            public MaskMode MaskClipMode
            {
                get
                {
                    return this.relatedControl.MaskClipMode;
                }
                set
                {
                    PropertyDescriptor pdAnchor = TypeDescriptor.GetProperties(this.relatedControl)["MaskClipMode"];
                    pdAnchor.SetValue(this.relatedControl, value);
                }
            }
            #endregion

            #region .   Mask Display Mode   .
            // Properties that are targets of DesignerActionPropertyItem entries.
            public MaskMode MaskDisplayMode
            {
                get
                {
                    return this.relatedControl.MaskDisplayMode;
                }
                set
                {
                    PropertyDescriptor pdAnchor = TypeDescriptor.GetProperties(this.relatedControl)["MaskDisplayMode"];
                    pdAnchor.SetValue(this.relatedControl, value);
                }
            }
            #endregion

            #region .   Enabled   .
            public bool EnabledCurrencyEditor
            {
                get
                {
                    return this.relatedControl.EnabledCurrencyEditor;
                }
                set
                {
                    PropertyDescriptor pdAnchor = TypeDescriptor.GetProperties(this.relatedControl)["EnabledCurrencyEditor"];
                    pdAnchor.SetValue(this.relatedControl, value);
                }
            }
            #endregion

            #region .   Tab Index   .
            public int TabIndexCurrencyEditor
            {
                get
                {
                    return this.relatedControl.TabIndexCurrencyEditor;
                }
                set
                {
                    PropertyDescriptor pdAnchor = TypeDescriptor.GetProperties(this.relatedControl)["TabIndexCurrencyEditor"];
                    pdAnchor.SetValue(this.relatedControl, value);
                }
            }
            #endregion

            #region .   Tab Stop   .
            public bool TabStopCurrencyEditor
            {
                get
                {
                    return this.relatedControl.TabStopCurrencyEditor;
                }
                set
                {
                    PropertyDescriptor pdAnchor = TypeDescriptor.GetProperties(this.relatedControl)["TabStopCurrencyEditor"];
                    pdAnchor.SetValue(this.relatedControl, value);
                }
            }
            #endregion

            #endregion

            #region .   Get Sorted Action Items   .
            // This method creates and populates the DesignerActionItemCollection which is used to 
            // display smart tag items.
            public override DesignerActionItemCollection GetSortedActionItems()
            {
                DesignerActionItemCollection items = new DesignerActionItemCollection();

                #region .   Appearance   .

                #region .   Border Style   .
                items.Add(new DesignerActionHeaderItem("Appearance"));
                items.Add(new DesignerActionPropertyItem(
                    "BorderStyleCurrencyEditor",
                    "BorderStyle",
                    "Appearance"));
                #endregion

                #region .   Spin Button Display Style   .
                items.Add(new DesignerActionPropertyItem(
                    "SpinButtonDisplayStyle",
                    "SpinButtonDisplayStyle",
                    "Appearance",
                    "Gets/sets the display style for the controls spin buttons."));
                #endregion

                #region .   Spin Button Alignment   .
                items.Add(new DesignerActionPropertyItem(
                    "SpinButtonAlignment",
                    "SpinButtonAlignment",
                    "Appearance",
                    "Gets/sets the alignment for the controls spin buttons."));
                #endregion

                #region .   Use OS Themes   .
                items.Add(new DesignerActionPropertyItem(
                    "UseOsThemes",
                    "UseOsThemes",
                    "Appearance",
                    "Indicates whether the elements of a control may be rendered using the operating system theme rendering."));
                #endregion

                #endregion

                #region .   Behavior   .

                #region .   Currency Editor Enabled   .
                items.Add(new DesignerActionHeaderItem("Behavior"));
                items.Add(new DesignerActionPropertyItem(
                    "EnabledCurrencyEditor",
                    "Enabled",
                    "Behavior",
                    "Indicates whether the control is enabled."));
                #endregion

                #region .   Mask Input   .
                items.Add(new DesignerActionPropertyItem(
                    "MaskInput",
                    "MaskInput",
                    "Behavior",
                    "Gets/sets the input mask used by the control."));
                #endregion

                #region .   Spin Wrap   .
                items.Add(new DesignerActionPropertyItem(
                    "SpinWrap",
                    "SpinWrap",
                    "Behavior",
                    "Gets/sets a value indicating whether the controls spin buttons should wrap its value."));
                #endregion

                #region .   Format String   .
                items.Add(new DesignerActionPropertyItem(
                    "FormatString",
                    "FormatString",
                    "Behavior",
                    "Gets/sets the format string used by the control."));
                #endregion

                #region .   Min Value   .
                items.Add(new DesignerActionPropertyItem(
                    "MinValue",
                    "MinValue",
                    "Behavior",
                    "Gets/sets the control's minimum allowable value."));
                #endregion

                #region .   Max Value   .
                items.Add(new DesignerActionPropertyItem(
                    "MaxValue",
                    "MaxValue",
                    "Behavior",
                    "Gets/sets the control's maximum allowable value."));
                #endregion

                #region .   Mask Clip Mode   .
                items.Add(new DesignerActionPropertyItem(
                    "MaskClipMode",
                    "MaskClipMode",
                    "Behavior",
                    "Gets/sets the mask that is applied to the controls text when it is copied to the clipboard."));
                #endregion

                #region .   Mask Display Mode   .
                items.Add(new DesignerActionPropertyItem(
                    "MaskDisplayMode",
                    "MaskDisplayMode",
                    "Behavior",
                    "Gets/sets the mask that is applied to the text displayed by the control."));
                #endregion

                #region .   Tab Index   .
                items.Add(new DesignerActionPropertyItem(
                    "TabIndexCurrencyEditor",
                    "TabIndex",
                    "Behavior",
                    "Determines the index in the TAB order that this control will occupy."));
                #endregion

                #region .   Tab Stop   .
                items.Add(new DesignerActionPropertyItem(
                    "TabStopCurrencyEditor",
                    "TabStop",
                    "Behavior",
                    "Indicates wheter the user can use the TAB key to give focus to the control."));
                #endregion

                #endregion

                #region .   Misc   .

                #region .   Prompt Character   .
                items.Add(new DesignerActionHeaderItem("Miscellaneous"));
                items.Add(new DesignerActionPropertyItem(
                    "PromptChar",
                    "PromptChar",
                    "Miscellaneous",
                    "Character used for prompts."));
                #endregion

                #region .   Tab Navigation   .
                items.Add(new DesignerActionPropertyItem(
                    "TabNavigation",
                    "TabNavigation",
                    "Miscellaneous"));
                #endregion

                #endregion

                #region .   Prompt   .

                #region .   Prompt Manager   .
                items.Add(new DesignerActionHeaderItem("Prompt"));
                items.Add(new DesignerActionPropertyItem(
                    "PromptManager",
                    "Prompt Manager",
                    "Prompt"));
                #endregion

                #region .   Field Name   .
                items.Add(new DesignerActionPropertyItem(
                    "FieldName",
                    "Field Name",
                    "Prompt"));
                #endregion

                #region .   Change Method   .
                items.Add(new DesignerActionPropertyItem(
                    "ChangeMethod",
                    "Change Method",
                    "Prompt"));
                #endregion

                #region .   Suppress Error   .
                items.Add(new DesignerActionPropertyItem(
                    "SuppressError",
                    "Suppress Error",
                    "Prompt"));
                #endregion

                #endregion

                return items;
            }
            #endregion

            #region .   IEditType Members   .
            Type IEditType.EditType
            {
                get
                {
                    return typeof(int);
                }
            }
            #endregion
        }
    }
}