using System;
using System.Collections;
using System.ComponentModel;
using System.ComponentModel.Design;
using System.Drawing;
using System.Drawing.Design;
using System.Windows.Forms;
using System.Windows.Forms.Design;
using System.Windows.Forms.Design.Behavior;
using Shared;
using Infragistics.Shared;
using Infragistics.Win;
using Infragistics.Win.UltraWinMaskedEdit;
using Infragistics.Win.UltraWinEditors;

namespace Shared.BaseClasses
{
    [System.Security.Permissions.PermissionSet(System.Security.Permissions.SecurityAction.Demand, Name = "FullTrust")]
    public class DateBaseDesigner : ControlDesigner
    {
        #region .   Variables   .
        // References to designer services, for convenience.
        private IComponentChangeService changeService = null;
        private ISelectionService selectionService = null;
        private BehaviorService behaviorSvc = null;

        // This is the collection of DesignerActionLists that
        // defines the smart tags offered on the control. 
        private DesignerActionListCollection actionLists = null;
        #endregion

        #region .   Date Base Designer   .
        public DateBaseDesigner()
        {   
        }

        #region .   Dispose   .
        protected override void Dispose(bool disposing)
        {
            if (disposing)
            {                
            }

            base.Dispose(disposing);
        }
        #endregion

        #region .   Initialize   .
        // This method is where the designer initializes its state when
        // it is created.
        public override void Initialize(IComponent component)
        {
            base.Initialize(component);

            // Connect to various designer services.
            InitializeServices();
        }

        #region .   New Component   .
        // This demonstrates changing the appearance of a control while
        // it is being designed. In this case, the BackColor property is
        // set to LightBlue. 
        public override void InitializeNewComponent(IDictionary defaultValues)
        {
            base.InitializeNewComponent(defaultValues);
        }
        #endregion

        #region .   Services   .
        // This utility method connects the designer to various services.
        // These references are cached for convenience.
        private void InitializeServices()
        {
            // Acquire a reference to IComponentChangeService.
            this.changeService =
                GetService(typeof(IComponentChangeService))
                as IComponentChangeService;

            // Acquire a reference to ISelectionService.
            this.selectionService =
                GetService(typeof(ISelectionService))
                as ISelectionService;

            // Acquire a reference to BehaviorService.
            this.behaviorSvc =
                GetService(typeof(BehaviorService))
                as BehaviorService;
        }
        #endregion

        #endregion

        #region .   Designer Action List Collection   .
        // This method creates the DesignerActionList on demand, causing
        // smart tags to appear on the control being designed.
        public override DesignerActionListCollection ActionLists
        {
            get
            {
                if (null == actionLists)
                {
                    actionLists = new DesignerActionListCollection();

                    actionLists.Add(
                        new ActionList(this.Component));
                }

                return actionLists;
            }
        }
        #endregion

        #endregion

        public class ActionList : System.ComponentModel.Design.DesignerActionList
        {
            #region .   Action List   .
            // Cache a reference to the control.
            private DateBase relatedControl;

            //The constructor associates the control with the smart tag list.
            public ActionList(IComponent component)
                : base(component)
            {
                this.relatedControl = component as DateBase;
            }
            #endregion

            #region .   Variables   .

            #region .   BackColor   .
            public Color BackColorDateTimeEditor
            {
                get
                {
                    return this.relatedControl.BackColorDateTimeEditor;
                }
                set
                {
                    PropertyDescriptor pdAnchor = TypeDescriptor.GetProperties(this.relatedControl)["BackColorDateTimeEditor"];
                    pdAnchor.SetValue(this.relatedControl, value);
                }
            }
            #endregion

            #region .   BackColor Disabled   .
            public Color BackColorDisabledDateTimeEditor
            {
                get
                {
                    return this.relatedControl.BackColorDisabledDateTimeEditor;
                }
                set
                {
                    PropertyDescriptor pdAnchor = TypeDescriptor.GetProperties(this.relatedControl)["BackColorDisabledDateTimeEditor"];
                    pdAnchor.SetValue(this.relatedControl, value);
                }
            }
            #endregion

            #region .   Date Enabled   .
            public bool EnabledDateTimeEditor
            {
                get
                {
                    return this.relatedControl.EnabledDateTimeEditor;
                }
                set
                {
                    PropertyDescriptor pdAnchor = TypeDescriptor.GetProperties(this.relatedControl)["EnabledDateTimeEditor"];
                    pdAnchor.SetValue(this.relatedControl, value);
                }
            }
            #endregion

            #region .   Tab Index   .
            public int TabIndexDateTimeEditor
            {
                get
                {
                    return this.relatedControl.TabIndexDateTimeEditor;
                }
                set
                {
                    PropertyDescriptor pdAnchor = TypeDescriptor.GetProperties(this.relatedControl)["TabIndexDateTimeEditor"];
                    pdAnchor.SetValue(this.relatedControl, value);
                }
            }
            #endregion

            #region .   Tab Stop   .
            public bool TabStopDateTimeEditor
            {
                get
                {
                    return this.relatedControl.TabStopDateTimeEditor;
                }
                set
                {
                    PropertyDescriptor pdAnchor = TypeDescriptor.GetProperties(this.relatedControl)["TabStopDateTimeEditor"];
                    pdAnchor.SetValue(this.relatedControl, value);
                }
            }
            #endregion

            #endregion

            #region .   Get Sorted Action Items   .
            // This method creates and populates the DesignerActionItemCollection which is used to 
            // display smart tag items.
            public override DesignerActionItemCollection GetSortedActionItems()
            {
                DesignerActionItemCollection items = new DesignerActionItemCollection();

                #region .   Behavior   .

                #region .   Date Enabled   .
                items.Add(new DesignerActionHeaderItem("Behavior"));
                items.Add(new DesignerActionPropertyItem(
                    "EnabledDateTimeEditor",
                    "Enabled",
                    "Behavior",
                    "Indicates whether the control is enabled."));
                #endregion

                #region .   Tab Index   .
                items.Add(new DesignerActionPropertyItem(
                    "TabIndexDateTimeEditor",
                    "TabIndex",
                    "Behavior",
                    "Determines the index in the TAB order that this control will occupy."));
                #endregion

                #region .   Tab Stop   .
                items.Add(new DesignerActionPropertyItem(
                    "TabStopDateTimeEditor",
                    "TabStop",
                    "Behavior",
                    "Indicates wheter the user can use the TAB key to give focus to the control."));
                #endregion

                #endregion

                #region .   Prompt   .

                #region .   Prompt Manager   .
                items.Add(new DesignerActionHeaderItem("Prompt"));
                items.Add(new DesignerActionPropertyItem(
                    "PromptManager",
                    "Prompt Manager",
                    "Prompt"));
                #endregion

                #region .   Field Name   .
                items.Add(new DesignerActionPropertyItem(
                    "FieldName",
                    "Field Name",
                    "Prompt"));
                #endregion

                #region .   Change Method   .
                items.Add(new DesignerActionPropertyItem(
                    "ChangeMethod",
                    "Change Method",
                    "Prompt"));
                #endregion

                #region .   Suppress Error   .
                items.Add(new DesignerActionPropertyItem(
                    "SuppressError",
                    "Suppress Error",
                    "Prompt"));
                #endregion

                #endregion

                return items;
            }
            #endregion
        }
    }
}
